@@ -4,24 +4,20 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
-
+from accounts.get_accounts import GetAccounts
+from blockchain.block.get_block import GetBlock
 from wallet.wallet import Address
 
-from blockchain.block.get_block import GetBlock
 
-from accounts.get_accounts import GetAccounts
-
-
-def GetBalance(user, block):
+def GetBalance(block, user):
     """
     Returns the users balance.
     """
 
     balance = -GetBlock().minumum_transfer_amount
-    user = "".join(
-        [l.strip() for l in user.splitlines() if l and not l.startswith("-----")]
-    )
+    user = "".join([
+        l.strip() for l in user.splitlines() if l and not l.startswith("-----")
+    ])
     user = Address(user)
     for Accounts in GetAccounts():
 
