@@ -4,23 +4,22 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
 import os
 
 from kivy import Config
-Config.set('graphics', 'width', '700')
-Config.set('graphics', 'height', '450')
-Config.set('graphics', 'minimum_width', '700')
-Config.set('graphics', 'minimum_height', '450')
-Config.set('input', 'mouse', 'mouse,disable_multitouch')
-
 from kivy.lang import Builder
-
 from kivymd.app import MDApp
-
 from lib.config_system import get_config
-os.environ["DECENTRA_ROOT"] = get_config()["main_folder"]
+from lib.log import get_logger
+from loguru import logger
 
+Config.set("graphics", "width", "700")
+Config.set("graphics", "height", "450")
+Config.set("graphics", "minimum_width", "700")
+Config.set("graphics", "minimum_height", "450")
+Config.set("input", "mouse", "mouse,disable_multitouch")
+
+os.environ["DECENTRA_ROOT"] = get_config()["main_folder"]
 
 KV_DIR = f"{os.environ['DECENTRA_ROOT']}/gui_lib/libs/kv/"
 
@@ -44,6 +43,8 @@ ScreenManager:
 
 """
 
+logger = get_logger("GUI")
+
 
 class GUI(MDApp):
     """
@@ -58,7 +59,6 @@ class GUI(MDApp):
         self.title = "Decentra Network"
         self.icon = f"{os.environ['DECENTRA_ROOT']}/gui_lib/images/logo.ico"
 
-
     def build(self):
         """
         Some configurations.
@@ -67,52 +67,53 @@ class GUI(MDApp):
         self.theme_cls.primary_palette = "Green"
         FONT_PATH = f"{os.environ['DECENTRA_ROOT']}/gui_lib/fonts/"
 
-        self.theme_cls.font_styles.update(
-            {
-                "H1": [FONT_PATH + "RobotoCondensed-Light", 96, False, -1.5],
-                "H2": [FONT_PATH + "RobotoCondensed-Light", 60, False, -0.5],
-                "H3": [FONT_PATH + "Eczar-Regular", 48, False, 0],
-                "H4": [FONT_PATH + "RobotoCondensed-Regular", 34, False, 0.25],
-                "H5": [FONT_PATH + "RobotoCondensed-Regular", 24, False, 0],
-                "H6": [FONT_PATH + "RobotoCondensed-Bold", 20, False, 0.15],
-                "Subtitle1": [
-                    FONT_PATH + "RobotoCondensed-Regular",
-                    16,
-                    False,
-                    0.15,
-                ],
-                "Subtitle2": [
-                    FONT_PATH + "RobotoCondensed-Medium",
-                    14,
-                    False,
-                    0.1,
-                ],
-                "Body1": [FONT_PATH + "Eczar-Regular", 16, False, 0.5],
-                "Body2": [FONT_PATH + "RobotoCondensed-Light", 14, False, 0.25],
-                "Button": [FONT_PATH + "RobotoCondensed-Bold", 14, True, 1.25],
-                "Caption": [
-                    FONT_PATH + "RobotoCondensed-Regular",
-                    12,
-                    False,
-                    0.4,
-                ],
-                "Overline": [
-                    FONT_PATH + "RobotoCondensed-Regular",
-                    10,
-                    True,
-                    1.5,
-                ],
-            }
-        )
-        
+        self.theme_cls.font_styles.update({
+            "H1": [FONT_PATH + "RobotoCondensed-Light", 96, False, -1.5],
+            "H2": [FONT_PATH + "RobotoCondensed-Light", 60, False, -0.5],
+            "H3": [FONT_PATH + "Eczar-Regular", 48, False, 0],
+            "H4": [FONT_PATH + "RobotoCondensed-Regular", 34, False, 0.25],
+            "H5": [FONT_PATH + "RobotoCondensed-Regular", 24, False, 0],
+            "H6": [FONT_PATH + "RobotoCondensed-Bold", 20, False, 0.15],
+            "Subtitle1": [
+                FONT_PATH + "RobotoCondensed-Regular",
+                16,
+                False,
+                0.15,
+            ],
+            "Subtitle2": [
+                FONT_PATH + "RobotoCondensed-Medium",
+                14,
+                False,
+                0.1,
+            ],
+            "Body1": [FONT_PATH + "Eczar-Regular", 16, False, 0.5],
+            "Body2": [FONT_PATH + "RobotoCondensed-Light", 14, False, 0.25],
+            "Button": [FONT_PATH + "RobotoCondensed-Bold", 14, True, 1.25],
+            "Caption": [
+                FONT_PATH + "RobotoCondensed-Regular",
+                12,
+                False,
+                0.4,
+            ],
+            "Overline": [
+                FONT_PATH + "RobotoCondensed-Regular",
+                10,
+                True,
+                1.5,
+            ],
+        })
+
         return Builder.load_string(KV)
 
+
 def start():
     """
     Start the GUI mode.
     """
-    
+
+    logger.info("Starting GUI mode")
     GUI().run()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     start()
