@@ -12,6 +12,8 @@ import os
 from lib.config_system import get_config
 from config import MY_TRANSACTION_PATH
 
+from transactions.get_my_transaction import GetMyTransaction
+
 
 def SavetoMyTransaction(tx):
     """
@@ -24,21 +26,3 @@ def SavetoMyTransaction(tx):
     os.chdir(get_config()["main_folder"])
     with open(MY_TRANSACTION_PATH, "wb") as my_transaction_file:
         pickle.dump(currently_list, my_transaction_file, protocol=2)
-
-
-def GetMyTransaction():
-    """
-    Returns the transaction db.
-    """
-
-    os.chdir(get_config()["main_folder"])
-
-    if not os.path.exists(MY_TRANSACTION_PATH):
-        return []
-
-    
-    with open(MY_TRANSACTION_PATH, "rb") as my_transaction_file:
-        obj = pickle.load(my_transaction_file)
-        if not len(obj) == 1:
-            obj.remove(obj[0])
-        return obj
